# ListAgentConnectorResponse

Response object for agent connector list
## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**agent_connectors** | [**list[AgentConnector]**](AgentConnector.md) | List of agent connectors | 
**limit** | **int** | Limit on the number of rows in the response | 
**page_at_id** | **str** | The id to request in the pagination query to get the next page. | [optional] 

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)


